@@ -463,11 +463,14 @@ class IO(object):
                     newbuffer.data.x.append(segment)
                     newbuffer.plot.axis.x.lines.append(segment[0])
 
+                y_segments = [] # used to save corrected y_data in meta_dict
                 for j, segment in enumerate(Ydata):
                     signal_shift = 0.0
                     if j > 0:
-                        signal_shift = segment[0]-Ydata[j-1][-1]
-                    newbuffer.data.y.append(segment - signal_shift)
+                        signal_shift = segment[1] - Ydata[j-1][-1]
+                    cor_y = segment - signal_shift
+                    newbuffer.data.y.append(cor_y)
+                    y_segments.append(cor_y)
 
                 newbuffer.data.z.set([float(MolarConcentration[-2])] * newbuffer.data.y.length())
 
@@ -478,7 +481,7 @@ class IO(object):
                 newbuffer.plot.axis.x.title.set("Time (s)")
                 newbuffer.plot.axis.y.title.set("Response (nm)")
                 newbuffer.plot.axis.x.lines.show()
-                newbuffer.meta_dict = {'xData': Xdata, 'yData': Ydata,
+                newbuffer.meta_dict = {'xData': Xdata, 'yData': y_segments,
                                        'stepName': StepName, 'actualTime': ActualTime, 'sensorType': SensorType,
                                        'stepStatus': StepStatus, 'stepType': StepType, 'concentration': Concentration,
                                        'molarConcentration':MolarConcentration, 'sampleID':SampleID,
